==> customer-link-project-api-1.0.1-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app86760/vo/RecommendNewVO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app86760.vo;

import com.alibaba.fastjson.annotation.JSONField;

import java.util.List;

/**
 * write_your_class_description_here
 *
 * @author xulei
 * @since 1.0.0
 */
public class RecommendNewVO {

    /**
     * 灵活存取利率最大值
     */
    @JSONField(name = "MAXSMARATE")
    private String maxSmaRate;

    /**
     * 灵活存取利率最小值
     */
    @JSONField(name = "MINSMARATE")
    private String minSmaRate;

    /**
     * 1-3个月利率最大值
     */
    @JSONField(name = "MAXMIDRATE")
    private String maxMidRate;

    /**
     * 1-3个月利率最小值
     */
    @JSONField(name = "MINMIDRATE")
    private String minMidRate;

    /**
     * 3-6个月利率最大值
     */
    @JSONField(name = "MAXLONRATE")
    private String maxLonRate;

    /**
     * 3-6个月利率最小值
     */
    @JSONField(name = "MINLONRATE")
    private String minLonRate;

    /**
     * 6-12个月利率最大值
     */
    @JSONField(name = "MAXLONMIDRATE")
    private String maxLonMidRate;

    /**
     * 6-12个月利率最小值
     */
    @JSONField(name = "MINLONMIDRATE")
    private String minLonMidRate;

    /**
     * 12个月以上利率最大值
     */
    @JSONField(name = "MAXLONMAXRATE")
    private String maxLonMaxRate;

    /**
     * 推荐产品数据1004-灵活存取
     */
    private List<ProductVO> smaList;

    /**
     * 推荐产品数据1005-1-3个月
     */
    private List<ProductVO> midList;

    /**
     * 推荐产品数据1006-3-6个月
     */
    private List<ProductVO> lonList;

    /**
     * 推荐产品数据1023-6-12个月
     */
    private List<ProductVO> lonMidList;

    /**
     * 推荐产品数据1024-12个月以上
     */
    private List<ProductVO> lonMaxList;

    public String getMaxSmaRate() {
        return maxSmaRate;
    }

    public void setMaxSmaRate(String maxSmaRate) {
        this.maxSmaRate = maxSmaRate;
    }

    public String getMinSmaRate() {
        return minSmaRate;
    }

    public void setMinSmaRate(String minSmaRate) {
        this.minSmaRate = minSmaRate;
    }

    public String getMaxMidRate() {
        return maxMidRate;
    }

    public void setMaxMidRate(String maxMidRate) {
        this.maxMidRate = maxMidRate;
    }

    public String getMinMidRate() {
        return minMidRate;
    }

    public void setMinMidRate(String minMidRate) {
        this.minMidRate = minMidRate;
    }

    public String getMaxLonRate() {
        return maxLonRate;
    }

    public void setMaxLonRate(String maxLonRate) {
        this.maxLonRate = maxLonRate;
    }

    public String getMinLonRate() {
        return minLonRate;
    }

    public void setMinLonRate(String minLonRate) {
        this.minLonRate = minLonRate;
    }

    public String getMaxLonMidRate() {
        return maxLonMidRate;
    }

    public void setMaxLonMidRate(String maxLonMidRate) {
        this.maxLonMidRate = maxLonMidRate;
    }

    public String getMinLonMidRate() {
        return minLonMidRate;
    }

    public void setMinLonMidRate(String minLonMidRate) {
        this.minLonMidRate = minLonMidRate;
    }

    public String getMaxLonMaxRate() {
        return maxLonMaxRate;
    }

    public void setMaxLonMaxRate(String maxLonMaxRate) {
        this.maxLonMaxRate = maxLonMaxRate;
    }

    public List<ProductVO> getSmaList() {
        return smaList;
    }

    public void setSmaList(List<ProductVO> smaList) {
        this.smaList = smaList;
    }

    public List<ProductVO> getMidList() {
        return midList;
    }

    public void setMidList(List<ProductVO> midList) {
        this.midList = midList;
    }

    public List<ProductVO> getLonList() {
        return lonList;
    }

    public void setLonList(List<ProductVO> lonList) {
        this.lonList = lonList;
    }

    public List<ProductVO> getLonMidList() {
        return lonMidList;
    }

    public void setLonMidList(List<ProductVO> lonMidList) {
        this.lonMidList = lonMidList;
    }

    public List<ProductVO> getLonMaxList() {
        return lonMaxList;
    }

    public void setLonMaxList(List<ProductVO> lonMaxList) {
        this.lonMaxList = lonMaxList;
    }
}

==> customer-link-project-api-1.0.31-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app86760/vo/RecommendNewVO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app86760.vo;

import com.alibaba.fastjson.annotation.JSONField;

import java.util.List;

/**
 * write_your_class_description_here
 *
 * @author xulei
 * @since 1.0.0
 */
public class RecommendNewVO extends BaseVO {

    /**
     * 灵活存取利率最大值
     */
    @JSONField(name = "MAXSMARATE")
    private String maxSmaRate;

    /**
     * 灵活存取利率最小值
     */
    @JSONField(name = "MINSMARATE")
    private String minSmaRate;

    /**
     * 1-3个月利率最大值
     */
    @JSONField(name = "MAXMIDRATE")
    private String maxMidRate;

    /**
     * 1-3个月利率最小值
     */
    @JSONField(name = "MINMIDRATE")
    private String minMidRate;

    /**
     * 3-6个月利率最大值
     */
    @JSONField(name = "MAXLONRATE")
    private String maxLonRate;

    /**
     * 3-6个月利率最小值
     */
    @JSONField(name = "MINLONRATE")
    private String minLonRate;

    /**
     * 6-12个月利率最大值
     */
    @JSONField(name = "MAXLONMIDRATE")
    private String maxLonMidRate;

    /**
     * 6-12个月利率最小值
     */
    @JSONField(name = "MINLONMIDRATE")
    private String minLonMidRate;

    /**
     * 12个月以上利率最大值
     */
    @JSONField(name = "MAXLONMAXRATE")
    private String maxLonMaxRate;

    /**
     * 推荐产品数据1004-灵活存取
     */
    private List<ProductVO> smaList;

    /**
     * 推荐产品数据1005-1-3个月
     */
    private List<ProductVO> midList;

    /**
     * 推荐产品数据1006-3-6个月
     */
    private List<ProductVO> lonList;

    /**
     * 推荐产品数据1023-6-12个月
     */
    private List<ProductVO> lonMidList;

    /**
     * 推荐产品数据1024-12个月以上
     */
    private List<ProductVO> lonMaxList;

    public String getMaxSmaRate() {
        return maxSmaRate;
    }

    public void setMaxSmaRate(String maxSmaRate) {
        this.maxSmaRate = maxSmaRate;
    }

    public String getMinSmaRate() {
        return minSmaRate;
    }

    public void setMinSmaRate(String minSmaRate) {
        this.minSmaRate = minSmaRate;
    }

    public String getMaxMidRate() {
        return maxMidRate;
    }

    public void setMaxMidRate(String maxMidRate) {
        this.maxMidRate = maxMidRate;
    }

    public String getMinMidRate() {
        return minMidRate;
    }

    public void setMinMidRate(String minMidRate) {
        this.minMidRate = minMidRate;
    }

    public String getMaxLonRate() {
        return maxLonRate;
    }

    public void setMaxLonRate(String maxLonRate) {
        this.maxLonRate = maxLonRate;
    }

    public String getMinLonRate() {
        return minLonRate;
    }

    public void setMinLonRate(String minLonRate) {
        this.minLonRate = minLonRate;
    }

    public String getMaxLonMidRate() {
        return maxLonMidRate;
    }

    public void setMaxLonMidRate(String maxLonMidRate) {
        this.maxLonMidRate = maxLonMidRate;
    }

    public String getMinLonMidRate() {
        return minLonMidRate;
    }

    public void setMinLonMidRate(String minLonMidRate) {
        this.minLonMidRate = minLonMidRate;
    }

    public String getMaxLonMaxRate() {
        return maxLonMaxRate;
    }

    public void setMaxLonMaxRate(String maxLonMaxRate) {
        this.maxLonMaxRate = maxLonMaxRate;
    }

    public List<ProductVO> getSmaList() {
        return smaList;
    }

    public void setSmaList(List<ProductVO> smaList) {
        this.smaList = smaList;
    }

    public List<ProductVO> getMidList() {
        return midList;
    }

    public void setMidList(List<ProductVO> midList) {
        this.midList = midList;
    }

    public List<ProductVO> getLonList() {
        return lonList;
    }

    public void setLonList(List<ProductVO> lonList) {
        this.lonList = lonList;
    }

    public List<ProductVO> getLonMidList() {
        return lonMidList;
    }

    public void setLonMidList(List<ProductVO> lonMidList) {
        this.lonMidList = lonMidList;
    }

    public List<ProductVO> getLonMaxList() {
        return lonMaxList;
    }

    public void setLonMaxList(List<ProductVO> lonMaxList) {
        this.lonMaxList = lonMaxList;
    }
}
